/**
 * uGallery jQuery plugin
 * Author: Miro Zoricak (zoricak at udesign.sk)
 * Website: http://zori.udesign.sk
 * v 1.0 beta
 */
(function($){
	var images = [], settings;
	
	$.uGallery = function(userSettings){
		settings = $.uGallery.settings;
		$.extend(settings, userSettings);
		$("ul.uGallery")
			.wrap("<div class='gal-wrapper'></div>")
			.before("<div class='gal-main-viewer'></div>")
			.wrap("<div class='gal-thumbs-container'>")
			.removeClass("uGallery")
			.addClass("gal-thumbs")
			.mousemove($.uGallery.scrollThumbs)
			.each(function(index, el){
				$(this).find("li>img").each($.uGallery.setupImage);
			});
		setupCSS($(".gal-thumbs>li").size());
	}
	
	$.uGallery.setupImage = function(index, el){
		$(el).load(function(){													// wait for image to load (fixes webkit image dimension calculation problems)
			var width = $(el).width();
			var height = $(el).height();
			var newDim = proportionalResize({
				width: width,
				height: height
				}, {
				width: settings.thumbWidth,
				height: settings.thumbHeight
			});	// calculate thumb dimensions
			images[index] = {
				originalWidth: width,
				originalHeight: height,
				thumbWidth: newDim.width,
				thumbHeight: newDim.height,
				src: $(el).attr('src'),
				alt: $(el).attr('alt'),
				element: el
			};
			$(el).hide().css({
				width:newDim.width+"px", 
				height:newDim.height+"px",
				cursor: "pointer",
				paddingTop: (settings.thumbHeight-newDim.height)/2,
				msInterpolationMode: "bicubic"									// fixes the nearest-neighbour resizing on IE7 (IE6 still sucks ass)
			}).click(function(){
				$.uGallery.showFull(index);
			}).fadeTo(0, 0.4).hover(function(){
				$(this).stop().fadeTo(200, 1);
			}, function(){
				$(this).stop().fadeTo(500, 0.4);
			}).show();
			if(index == 0){
				$(el).trigger('click');
			}
		});
	}
	
	$.uGallery.showFull = function(index){
		var img = images[index];
		var image = $("<img src="+img.src+" alt="+img.alt+"/>");
		var dim = proportionalResize({
				width: img.originalWidth,
				height: img.originalHeight
			}, {
				width: settings.width - 20,
				height: settings.height - 20
			});
		image.css({
			width: dim.width+"px",
			height: dim.height+"px",
			paddingTop: (settings.height-dim.height)/2
		});
		var alt = $("<div class='gal-alt'>"+$(img).attr("alt")+"</div>");
		alt.css({
			clear: "both", 
			width: settings.width-40+"px", 
			padding: "10px", 
			"background-color": "black", 
			"margin": "auto",
			color: "white"
		});
		alt.fadeTo("fast", 0.6);
		$(".gal-main-viewer").fadeOut(settings.hideSpeed, function(){
				$(this).html(image).fadeIn(settings.showSpeed).append(alt);
				if(settings.displayAlt){
					$(".gal-alt").animate({marginTop: "-39px"}, 600);
				}
			}
		);
	}
	
	$.uGallery.scrollThumbs = function(e){
		var thumbs = $(".gal-thumbs");
		
		contentWidth = parseInt( thumbs.css( 'width' ) );		// The width of the div containing the thumbs
		movableWidth = contentWidth - settings.width;			// The difference between the thumbs and the viewport

		if ( movableWidth > 0 ) {
			var margin = -Math.round( ( e.clientX / settings.width ) * movableWidth ) + 10 ;
			thumbs.css( {"margin-left": margin + "px"} );
		}

	}
	
	$.uGallery.settings = {
		width: 420,
		height: 320,
		thumbWidth: 60,
		thumbHeight: 45,
		displayAlt: true,
		showSpeed: 700,			// how fast is the uBox show animation
		hideSpeed: 500,			// how fast is the uBox hide animation
		showImageAlt: true,		// true shows the transparent frame at the bottom of uBox containing image alt
		showImageAltSpeed: 800	// speed of the alt div fade-in animation
	}
	
	proportionalResize = function(dim, settings){											// compute maximum possible dimensions of an image that fits into rectangle defined by settings.thumbWidth and settings.thumbHeight
		var ratio = dim.width / dim.height;
		var nw = 0, nh = 0;
		if(dim.width > dim.height){
			nw = settings.width;
			nh = settings.width/ratio;
		} else {
			nw = settings.height*ratio;
			nh = settings.height;
		}
		return {width: nw, height: nh};
	}
	
	setupCSS = function(imgCount){
		$(".gal-thumbs>li").css({
			float: "left",
			width: settings.thumbWidth,
			height: settings.thumbHeight,
			border: "1px solid #555",
			marginLeft: "3px",
			"text-align": "center",
			"list-style-type": "none",
			padding: "3px"
		});
		
		$(".gal-wrapper").css({
			width: settings.width
		});
		
		$(".gal-thumbs").css({
			width: ( imgCount + 1 ) * ( settings.thumbWidth + imgCount ),
			height: settings.thumbHeight,
			margin: 0,
			padding: 0
		});
		
		$(".gal-thumbs-container").css({
			height: settings.thumbHeight + 10,
			overflow: "hidden",
			margin: "0px 10px 0px 10px"
		});
		
		$(".gal-main-viewer").css({
			width: settings.width,
			height: settings.height,
			"text-align": "center",
			overflow: "hidden"
		});
	}
})(jQuery)